Package: phenofit
Type: Package
Title: Extract Remote Sensing Vegetation Phenology
Version: 0.3.11
Authors@R: c(
    person("Dongdong", "Kong", role = c("aut", "cre"), email = "kongdd.sysu@gmail.com"),
    person("Mingzhong", "Xiao", role = c("aut"), email = "xmingzh@mail2.sysu.edu.cn"),
    person("Yongqiang", "Zhang", role = c("aut"), email = "yongqiang.zhang2014@gmail.com"),
    person("Xihui", "Gu", role = c("aut"), email = "guxh@cug.edu.cn"), 
    person("Jianjian", "Cui", role = c("aut"), email = "cuijj6@mail2.sysu.edu.cn"))
Description: 
    The merits of 'TIMESAT' and 'phenopix' are adopted. Besides, a simple and 
    growing season dividing method and a practical snow elimination method 
    based on Whittaker were proposed. 7 curve fitting methods and 4 phenology 
    extraction methods were provided. Parameters boundary are considered for 
    every curve fitting methods according to their ecological meaning. 
    And 'optimx' is used to select best optimization method for different 
    curve fitting methods.
    Reference:
    Kong, D., (2020). R package: A state-of-the-art Vegetation Phenology extraction 
    package, phenofit version 0.3.1, <doi:10.5281/zenodo.5150204>;
    Kong, D., Zhang, Y., Wang, D., Chen, J., & Gu, X. (2020). Photoperiod Explains 
    the Asynchronization Between Vegetation Carbon Phenology and Vegetation Greenness 
    Phenology. Journal of Geophysical Research: Biogeosciences, 125(8), e2020JG005636. 
    <doi:10.1029/2020JG005636>;
    Kong, D., Zhang, Y., Gu, X., & Wang, D. (2019). A robust method for reconstructing 
    global MODIS EVI time series on the Google Earth Engine. 
    ISPRS Journal of Photogrammetry and Remote Sensing, 155, 13–24;
    Zhang, Q., Kong, D., Shi, P., Singh, V.P., Sun, P., 2018. Vegetation phenology 
    on the Qinghai-Tibetan Plateau and its response to climate change (1982–2013). 
    Agric. For. Meteorol. 248, 408–417. <doi:10.1016/j.agrformet.2017.10.026>.
License: GPL-2 | file LICENSE
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
LinkingTo: Rcpp, RcppArmadillo
Depends: R (>= 3.1)
Imports: Rcpp, purrr, dplyr (>= 1.1.0), stringr, magrittr, lubridate,
        data.table, zoo, gridExtra, ggplot2, optimx, ucminf, numDeriv,
        methods, zeallot
Suggests: knitr, rmarkdown, testthat (>= 2.1.0)
URL: https://github.com/eco-hydro/phenofit
BugReports: https://github.com/eco-hydro/phenofit/issues
VignetteBuilder: knitr
NeedsCompilation: yes
Packaged: 2026-01-23 04:31:32 UTC; hydro
Author: Dongdong Kong [aut, cre],
  Mingzhong Xiao [aut],
  Yongqiang Zhang [aut],
  Xihui Gu [aut],
  Jianjian Cui [aut]
Maintainer: Dongdong Kong <kongdd.sysu@gmail.com>
Repository: CRAN
Date/Publication: 2026-01-23 09:30:06 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-26 14:28:48 UTC; unix
Archs: phenofit.so.dSYM
