# Generated by roxygen2: do not edit by hand

S3method(D1,fFIT)
S3method(D2,fFIT)
S3method(PhenoDeriv,default)
S3method(PhenoDeriv,fFIT)
S3method(PhenoGu,default)
S3method(PhenoGu,fFIT)
S3method(PhenoTrs,default)
S3method(PhenoTrs,fFIT)
S3method(curvature,fFIT)
S3method(get_GOF,fFIT)
S3method(get_GOF,fFITs)
S3method(get_GOF,list)
S3method(get_fitting,fFITs)
S3method(get_fitting,list)
S3method(get_param,fFIT)
S3method(get_param,fFITs)
S3method(get_param,list)
S3method(get_pheno,fFITs)
S3method(get_pheno,list)
S3method(get_pheno,rfit)
S3method(plot,fFIT)
S3method(plot,fFITs)
S3method(print,fFIT)
export("%<-%")
export("%<>%")
export("%>%")
export(D1)
export(D2)
export(FitDL.AG)
export(FitDL.AG2)
export(FitDL.Beck)
export(FitDL.Elmore)
export(FitDL.Gu)
export(FitDL.Klos)
export(FitDL.Zhang)
export(GOF)
export(I_optim)
export(I_optimx)
export(Logistic)
export(PhenoDeriv)
export(PhenoGu)
export(PhenoKl)
export(PhenoTrs)
export(R2_sign)
export(add_HeadTail)
export(brks2rfit)
export(check_input)
export(check_season_dt)
export(check_season_list)
export(check_ylu)
export(curvature)
export(curvefit)
export(curvefit0)
export(curvefits)
export(curvefits_LocalModel)
export(cv_coef)
export(date2doy)
export(doubleLog.AG)
export(doubleLog.AG2)
export(doubleLog.Beck)
export(doubleLog.Elmore)
export(doubleLog.Gu)
export(doubleLog.Klos)
export(doubleLog.Zhang)
export(doubleLog_AG)
export(doubleLog_Beck)
export(doubleLog_Elmore)
export(doubleLog_Gu)
export(doubleLog_Klos)
export(doubleLog_Zhang)
export(doy2date)
export(f_goal)
export(f_goal2)
export(find_season.default)
export(find_season.peaks)
export(findpeaks)
export(getBits)
export(getRealDate)
export(get_GOF)
export(get_fitting)
export(get_options)
export(get_param)
export(get_pheno)
export(init_AG)
export(init_AG2)
export(init_Beck)
export(init_Elmore)
export(init_Gu)
export(init_Klos)
export(init_Zhang)
export(init_lambda)
export(init_param)
export(kurtosis)
export(lambda_vcurve)
export(logistic)
export(make_date)
export(melt_list)
export(merge_LocalModels)
export(movmean)
export(opt_nlm)
export(opt_nlminb)
export(opt_optim)
export(opt_ucminf)
export(optim_pheno)
export(plot_curvefits)
export(plot_input)
export(plot_phenofit)
export(plot_season)
export(process_phenofit)
export(process_season)
export(qc_5l)
export(qc_FparLai)
export(qc_NDVI3g)
export(qc_NDVIv4)
export(qc_SPOT)
export(qc_StateQA)
export(qc_colors)
export(qc_levels)
export(qc_sentinel2)
export(qc_shapes)
export(qc_summary)
export(rcpp_SG)
export(rcpp_season_filter)
export(rcpp_wSG)
export(removeClosedExtreme)
export(roughFit)
export(season)
export(season_input)
export(season_mov)
export(set_options)
export(skewness)
export(smooth_wHANTS)
export(smooth_wSG)
export(smooth_wWHIT)
export(tidy_MOD13)
export(tidy_pheno)
export(v_curve)
export(wBisquare)
export(wBisquare0)
export(wChen)
export(wKong)
export(wSELF)
export(wTSM)
export(whit2)
import(ggplot2)
import(graphics)
import(magrittr)
import(numDeriv)
import(optimx)
import(stats)
import(zeallot)
importFrom(Rcpp,sourceCpp)
importFrom(data.table,":=")
importFrom(data.table,as.data.table)
importFrom(data.table,data.table)
importFrom(data.table,dcast)
importFrom(data.table,fread)
importFrom(data.table,fwrite)
importFrom(data.table,is.data.table)
importFrom(dplyr,across)
importFrom(dplyr,as_tibble)
importFrom(dplyr,group_by)
importFrom(dplyr,group_map)
importFrom(dplyr,group_modify)
importFrom(dplyr,mutate)
importFrom(dplyr,nth)
importFrom(dplyr,select)
importFrom(dplyr,starts_with)
importFrom(dplyr,ungroup)
importFrom(grDevices,cairo_pdf)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,dev.off)
importFrom(grid,grid.draw)
importFrom(grid,pushViewport)
importFrom(grid,viewport)
importFrom(gridExtra,arrangeGrob)
importFrom(lubridate,day)
importFrom(lubridate,ddays)
importFrom(lubridate,dyears)
importFrom(lubridate,is.Date)
importFrom(lubridate,leap_year)
importFrom(lubridate,make_date)
importFrom(lubridate,month)
importFrom(lubridate,yday)
importFrom(lubridate,year)
importFrom(lubridate,ymd)
importFrom(magrittr,"%<>%")
importFrom(magrittr,"%>%")
importFrom(methods,is)
importFrom(purrr,as_mapper)
importFrom(purrr,map)
importFrom(purrr,map_df)
importFrom(purrr,map_dfc)
importFrom(stringr,str_replace_all)
importFrom(ucminf,ucminf)
importFrom(utils,object.size)
importFrom(utils,str)
importFrom(zeallot,"%<-%")
importFrom(zoo,index)
importFrom(zoo,na.approx)
importFrom(zoo,na.spline)
importFrom(zoo,zoo)
useDynLib(phenofit, .registration = TRUE)
